@@ -193,6 +193,10 @@ std::time_t date_select_dialog(Gtk::Window& parent,
                                const Glib::ustring& title,
                                const std::time_t& curr_time);
 
+void no_matches_dialog(CtMainWin* pCtMainWin,
+                       const Glib::ustring& title,
+                       const Glib::ustring& message);
+
 // the All Matches Dialog
 void match_dialog(const Glib::ustring& title,
                   CtMainWin* ctMainWin,
@@ -219,26 +223,23 @@ bool link_handle_dialog(CtMainWin& ctMainWin,
                         Gtk::TreeIter sel_tree_iter,
                         CtLinkEntry& link_entries);
 
-struct FileSelectArgs
+struct CtFileSelectArgs
 {
-    FileSelectArgs(Gtk::Window* win) : pParentWin{win} {}
-
-    Gtk::Window*                pParentWin{nullptr};
     fs::path                    curr_folder;
     fs::path                    curr_file_name;
     Glib::ustring               filter_name;
     std::vector<Glib::ustring>  filter_pattern;
     std::vector<Glib::ustring>  filter_mime;
+    bool                        overwrite_confirmation{true};
 };
 
-// The Select file dialog, Returns the retrieved filepath or None
-std::string file_select_dialog(const FileSelectArgs& args);
+std::string file_select_dialog(Gtk::Window* pParentWin, const CtFileSelectArgs& args);
 
-// The Select folder dialog, returns the retrieved folderpath or None
-std::string folder_select_dialog(const std::string& curr_folder, Gtk::Window* pParentWin);
+std::string folder_select_dialog(Gtk::Window* pParentWin, const std::string& curr_folder);
 
-// The Save file as dialog, Returns the retrieved filepath or None
-std::string file_save_as_dialog(const FileSelectArgs& args);
+std::string file_save_as_dialog(Gtk::Window* pParentWin, const CtFileSelectArgs& args);
+
+std::string folder_save_as_dialog(Gtk::Window* pParentWin, const CtFileSelectArgs& args);
 
 // Insert/Edit Image
 Glib::RefPtr<Gdk::Pixbuf> image_handle_dialog(Gtk::Window& father_win,
@@ -251,19 +252,16 @@ Glib::ustring latex_handle_dialog(CtMainWin* pCtMainWin,
 bool codeboxhandle_dialog(CtMainWin* pCtMainWin,
                           const Glib::ustring& title);
 
-struct storage_select_args
+struct CtStorageSelectArgs
 {
-    CtMainWin*    pCtMainWin;
     CtDocType     ctDocType{CtDocType::None};
     CtDocEncrypt  ctDocEncrypt{CtDocEncrypt::None};
     Glib::ustring password;
     bool          showAutosaveOptions{false};
-
-    storage_select_args(CtMainWin* win) : pCtMainWin{win} {}
 };
 
-// Choose the CherryTree data storage type (xml or db) and protection
-bool choose_data_storage_dialog(storage_select_args& args);
+// Choose the CherryTree data storage type and protection
+bool choose_data_storage_dialog(CtMainWin* pCtMainWin, CtStorageSelectArgs& args);
 
 bool node_prop_dialog(const Glib::ustring &title,
                       CtMainWin* pCtMainWin,
